<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Contact;
use App\Models\Bank;
use App\User;
use Illuminate\Http\Request;

class BanksController extends Controller
{
    public function index()
    {
        $rows = Bank::all();
        return view('admin.banks.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.banks.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'bank_name' => 'required|max:191',
            'account_name' => 'required|max:191',
            'account_number' => 'required|numeric',
            'iban_number' => 'required|numeric',
            'image' => 'required|image'
            //'user_id' => 'exists:users,id'
        ]);
        Bank::create($request->all());
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('banks.index');
    }

    public function edit($id)
    {
        $row = Bank::find($id);
        return view('admin.banks.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $request->validate([
            'bank_name' => 'required|max:191',
            'account_name' => 'required|max:191',
            'account_number' => 'required|numeric',
            'iban_number' => 'required|numeric',
            'image' => 'nullable|image'
        ]);

        $bank = Bank::find($id);
        $bank->bank_name = $request->bank_name;
        $bank->account_name = $request->account_name;
        $bank->account_number = $request->account_number;
        $bank->iban_number = $request->iban_number;
        if($request->hasFile('image'))$bank->setImageAttribute();
        $bank->update();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('banks.index');
    }

    public function destroy($id)
    {
        Bank::destroy($id);
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('banks.index');
    }

}
