<?php

namespace App\Http\Controllers\Api\Salon;

use App\Http\Controllers\Controller;
use App\Http\Resources\OrderResource;
use App\Models\Notification;
use App\Models\Order;
use App\Models\Salon;
use App\Models\UserTokens;
use Illuminate\Http\Request;
use JWTAuth;
use Edujugon\PushNotification\PushNotification;

class OrdersController extends Controller
{
    public function order_details(Request $request, $id)
    {
        $order = Order::find($id);
        if (!$order) {
            return response()->json(['value' => false, 'msg' => 'لا يوجد طلب بهذا ID', 'code' => 422]);
        }
        return response()->json(['value' => true, 'data' => new OrderResource($order), 'code' => 200]);
    }

    public function orders(Request $request, $status)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }
        if ($status == 'waiting' || $status == 'in_progress' || $status == 'cancel' || $status == 'finish') {
            $rows = $user->salon->orders()->where('status', $status)->orderByDesc('id')->paginate(20);
            return OrderResource::collection($rows)->additional(['value' => true, 'code' => 200]);
        }
        return response()->json(['value' => false, 'msg' => 'ادخل الحالة الصحيحة ', 'code' => 422]);
    }

    public function accept_orders(Request $request, $id)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }

        $order = Order::where(['id' => $id, 'salon_id' => $user->salon->id])->first();
        if ($order) {
            $order->status = 'in_progress';
            $order->update();

            $salon = Salon::find($order->salon_id);
            $salon->order_counts +=1 ;
            $salon->update();
            $notification = new Notification();
            $notification['user_id'] = $order->user_id;
            $notification['order_id'] = $order->id;
            $notification['body'] = 'تم الموافقة على طلبك';
            $notification['type'] = 'salon_accept_order';
            $notification['salon_id'] = $order->salon->id;
            $notification->save();
            $tokens = UserTokens::where('user_id', $order->user_id)->where('status', 'connected')->get();

            foreach ($tokens as $token) {

                $push = new PushNotification('fcm');

                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title' => "تم الموافقة على طلبك",
                            'body' => "تم الموافقة على طلبك",
                            'type' => 'salon_accept_order',
                            'order_id' => $order->id,
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title' => "تم الموافقة على طلبك",
                            'body' => "تم الموافقة على طلبك",
                            'type' => 'salon_accept_order',
                            'order_id' => $order->id,
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title' => "تم الموافقة على طلبك",
                            'body' => "تم الموافقة على طلبك",
                            'type' => 'salon_accept_order',
                            'order_id' => $order->id,
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();
                }
            }
            return response()->json(['value' => true, 'data' => 'تم الموافقة', 'code' => 200]);
        }
        return response()->json(['value' => true, 'data' => 'رقم الطلب غير صحيح', 'code' => 422]);
    }


    public function cancel_order($id){
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }
        $order = Order::find($id);
        $order->status = 'cancel';
        $order->update();

        return response()->json(['value' => true, 'data' => 'تم إلغاء الطلب', 'code' => 200]);

    }

    public function finish_order($id)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }
        $order = Order::find($id);
        $order->status = 'finish';
        $order->update();

        return response()->json(['value' => true, 'data' => 'تم الإنتهاء من الطلب بنجاح', 'code' => 200]);

    }

    public function refuse_order($id)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong_token'), 'code' => 401]);
        }
        $order = Order::find($id);
        $order->status = 'salon_refuse';
        $order->update();

        $notification = new Notification();
        $notification['user_id'] = $order->user_id;
        $notification['order_id'] = $order->id;
        $notification['body'] = 'تم الرفض على طلبك';
        $notification['type'] = 'salon_refuse';
        $notification['salon_id'] = $order->salon->id;
        $notification->save();
        $tokens = UserTokens::where('user_id', $order->user_id)->where('status', 'connected')->get();

        foreach ($tokens as $token) {

            $push = new PushNotification('fcm');

            if ($token->device_type == 'ios') {
                $msg = [
                    'data' => [
                        'title' => "تم الرفض على طلبك",
                        'body' => "تم الرفض على طلبك",
                        'type' => 'salon_refuse',
                        'order_id' => $order->id,
                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'notification' => [
                        'title' => "تم الرفض على طلبك",
                        'body' => "تم الرفض على طلبك",
                        'type' => 'salon_refuse',
                        'order_id' => $order->id,
                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();

            } else {
                $msg = [
                    'data' => [
                        'title' => "تم الرفض على طلبك",
                        'body' => "تم الرفض على طلبك",
                        'type' => 'salon_refuse',
                        'order_id' => $order->id,
                        'sound' => 'default',
                        'click_action' => 'FCM_PLUGIN_ACTIVITY',
                    ],
                    'priority' => 'high',
                ];
                $push->setMessage($msg)
                    ->setDevicesToken($token->token)
                    ->send();
            }
        }






        return response()->json(['value' => true, 'data' => 'تم رفض الطلب', 'code' => 200]);

    }
}
