<?php

namespace App\Http\Resources;

use App\Models\Favourite;
use Illuminate\Http\Resources\Json\JsonResource;
use JWTAuth;

class SalonResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $favourite_status = false;
        if ($request->header('Authorization')){
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
            }

            $check = Favourite::where('user_id',$user->id)->where('salon_id',$this->id)->first();
            if ($check){
                $favourite_status = true;
            }else{
                $favourite_status = false;
            }

        }
        return [
            'id' => $this->id,
            'salon_title' => $this->salon_title ? $this->salon_title : '',
            'salon_mobile' => $this->user ? $this->user->mobile : '',
            'lat' => $this->user->lat ? $this->user->lat : '',
            'lng' => $this->user->lng ? $this->user->lng : '',
            'type' => $this->type ? $this->type : '',
            'details' => $this->details ? $this->details : '',
            'address' => $this->address ? $this->address : '',
            'always_open' => $this->always_open ? $this->always_open : '',
            'receive_notifications' => $this->receive_notifications ? $this->receive_notifications : '',
            'rate' => $this->total_rate,
            'favourite_status' => $favourite_status,
            'image' => $this->user->image ? asset('images/users/'.$this->user->image) : '',
            'salon_images'=>SalonImagesResource::collection($this->images),
            'categories_salon'=>$this->custom_categories('salon'),
            'categories_home'=>$this->custom_categories('home'),
            'salon_comments'=>SalonCommentsResource::collection($this->comments),
            'salon_times'=>SalonTimesResource::collection($this->salon_times),
            'packages'=>PackageResource::collection($this->packages),


          ];
    }
}
