<?php

namespace App\Http\Resources;

use App\Models\Favourite;
use App\User;
use JWTAuth;

use Illuminate\Http\Resources\Json\JsonResource;

class UserSalonResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $user = User::find($this->id);
        $myTTL = 60 * 60 * 365; //minutes
        JWTAuth::factory()->setTTL($myTTL);
        $token = JWTAuth::fromUser($user);

        $favourite_status = false;
        if ($request->header('Authorization')) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
            }

            $check = Favourite::where('user_id', $user->id)->where('salon_id', $this->salon->id)->first();
            if ($check) {
                $favourite_status = true;
            } else {
                $favourite_status = false;
            }

        }


        if ($this->salon){
            $is_complete = true;

            if ($this->salon->type == null || $this->salon->address == null || count($this->salon->salon_times) < 1 || $this->salon->salon_title == null || $this->image == null) {
                $is_complete = false;
            }
        }else{
            $is_complete = false;
        }


        return [
            'id' => $this->salon->id,
            'field_id' => $this->field_id ? (integer)$this->field_id : 0,
            'salon_id' => $this->salon->id,
            'username' => $this->username,
            'mobile' => $this->mobile,
            'email' => $this->email,
            'is_complete' => $is_complete,
            'city ' => $this->city ? new CityResource($this->city) : new \stdClass(),
            'city_name' => $this->city ? $this->city->name : '',
            'city_id' => $this->city ? (integer)$this->city->id : 0,
            'type' => $this->salon->type ? $this->salon->type : '',
            'address' => $this->salon->address ? $this->salon->address : '',
            'salon_title' => $this->salon->salon_title ? $this->salon->salon_title : '',
            'details' => $this->salon->details ? $this->salon->details : '',
            'always_open' => $this->salon->always_open ? $this->salon->always_open : '',
            'salon_times' => SalonTimeResource::collection($this->salon->salon_times()->get()),
            'images' => SalonImageResource::collection($this->salon->images()->get()),
//          'categories' => CategoryResource::collection($this->salon->categories()->get()),
            'packages' => PackageResource::collection($this->salon->packages),
            'salon_comments' => SalonCommentsResource::collection($this->salon->comments),
            'categories_salon' => $this->custom_categories('salon'),
            'categories_home' => $this->custom_categories('home'),
            'accounts' => SalonAccountResource::collection($user->salon->accounts()->get()),
            'status' => $this->status ? $this->status : '',
            'lat' => $this->lat ? $this->lat : '',
            'lng' => $this->lng ? $this->lng : '',
            'code' => $this->code ? (integer)$this->code : 0,
            'image_cover' => $this->salon->image ? asset('images/users/' . $this->salon->image) : '',
            'image' => $this->image ? asset('images/users/' . $this->image) : '',
            'wallet' => $this->salon->wallet ? $this->salon->wallet : '',
            'rate' => $this->salon->total_rate,
            'favourite_status' => $favourite_status,
            'token' => $token

        ];
    }
}
